/*
 * Copyright (c) 1998-2005 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */
package jgroup.relacs.gm;

import java.io.IOException;
import java.lang.reflect.Proxy;

import jgroup.core.GroupManager;
import jgroup.jini.LookupManager;
import jgroup.relacs.gmi.GroupInvocationHandler;

import org.apache.log4j.Logger;

/**
 *  Layer implementing the <code>GregLookupService</code> interface.
 *
 * @author Rohnny Moland
 * @since Jgroup 2.2
 */
public final class GregLookupLayer 
  implements GregLookupService
{

  // //////////////////////////////////////////////////////////////////////////////////////////
  // Logger
  // //////////////////////////////////////////////////////////////////////////////////////////

  /** Obtain logger for this class */
  private static final Logger log = Logger.getLogger(GregLookupLayer.class);

  // //////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  // //////////////////////////////////////////////////////////////////////////////////////////

  /** The group manager reference associated with this layer */
  private GroupManager gm;

  // //////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  // //////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Construct the <code>LookupLayer</code>.
   * 
   * @param gm
   *          The group manager object to which this layer is associated
   */
  private GregLookupLayer(GroupManager gm)
  {
    this.gm = gm;
  }

  // //////////////////////////////////////////////////////////////////////////////////////////
  // Static factory
  // //////////////////////////////////////////////////////////////////////////////////////////

  public static GregLookupLayer getLayer(GroupManager gm)
  {
    return new GregLookupLayer(gm);
  }

  // //////////////////////////////////////////////////////////////////////////////////////////
  // Layer interface methods
  // //////////////////////////////////////////////////////////////////////////////////////////

  public void addListener(Object listener)
  {
    // should never be called, since Lookup does not provide a listener
    // interface
  }

  // //////////////////////////////////////////////////////////////////////////////////////////
  // GregLookupService interface methods
  // //////////////////////////////////////////////////////////////////////////////////////////


  /*
   * (non-Javadoc)
   * 
   * @see jgroup.core.registry.LookupService#lookup(java.lang.String,
   *      java.lang.Class)
   */
  public Object lookup(String name) throws IOException
  {
    Object server = LookupManager.lookup(name);
    GroupInvocationHandler handler = (GroupInvocationHandler) Proxy.getInvocationHandler(server);
    handler.setGroupManager(gm);    
    return server;
  }

} // END of GregLookupLayer
