/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.test.hello;

import jgroup.core.registry.DependableRegistry;
import jgroup.core.registry.RegistryFactory;

/**
 *  Client program for Hello
 *
 *  @author Alberto Montresor
 *  @author Hein Meling
 *  @since Jgroup 0.1
 */
public class LeaseClient
{

  public static void main(String argv[])
    throws Exception
  {
    /*
     * Obtain a proxy for the depedable registry running in the
     * distributed system described in the config.xml file.
     */
    DependableRegistry registry = RegistryFactory.getRegistry();

    /*
     * Print the number of groups registered in the dependable registry
     */
    String[] bindings = registry.list();
    System.out.println("Number of elements: " + bindings.length);

    /*
     * Retrieve a proxy for an object group implementing the Hello
     * interface registered under the name "Jgroup/LeaseServer".
     */
    Hello server = (Hello) registry.lookup("Jgroup/LeaseServer");

    /*
     * Invoking method sayHello, which returns an object of type Answer
     * containing a string produced by the contacted object plus
     * the time at which the groups members installed the last view.
     */
    for (int i = 0; i < 20; i++) {
      Answer answer = server.sayHello();
      System.out.println(answer);
    }

    /*
     * There may be several threads blocking (e.g., the threads pooling
     * for registry instances), thus we just exit everything.
     */
    System.exit(0);
  }

} // END LeaseClient
