/*
 * Copyright (c) 1998-2004 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.test.multicast;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;

import jgroup.core.GroupManager;
import jgroup.core.JgroupException;
import jgroup.core.MemberId;
import jgroup.core.MembershipListener;
import jgroup.core.View;
import jgroup.core.multicast.MulticastListener;

/**
 * Simple multicast/total order test server.
 *
 * @author Hein Meling
 * @since Jgroup 2.2
 */
public class TotalOrderTestReceive
  implements MulticastListener, MembershipListener
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Protocol name used to distinguish messages from other protocols. */
  private static final String PROTOCOL_NAME = "Total2";


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  private TotalOrderTestReceive()
    throws JgroupException, IOException
  {
    GroupManager gm = GroupManager.getGroupManager(this);
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Main method
  ////////////////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] argv)
    throws Exception
  {
    TotalOrderTestReceive totc = new TotalOrderTestReceive();
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from MembershipListener
  ////////////////////////////////////////////////////////////////////////////////////////////

  public void viewChange(View view)
  {
    System.out.println("View: " + view);
  }

  public void prepareChange() { }

  public void hasLeft() { }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from MulticastListener
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Returns a string naming the protocol implemented by this multicast
   *  listener.
   */
  public String getProtocolName() 
  {
    return PROTOCOL_NAME;
  }

  public Object deliverStream(InputStream stream, MemberId sender, int seqNo)
  {
    String s = null;
    try {
      ObjectInputStream ios = new ObjectInputStream(stream);
      s = ios.readUTF();
    } catch (IOException e) {
      e.printStackTrace();
    }
    System.out.println("TotalOrderTestReceive: deliverStream: " + s);
    return null;
  }


  public Object deliverObject(Object obj, MemberId sender, int seqNo)
  {
    System.out.println("MulticastTestServer: deliverObject: " + obj);
    return null;
  }

} // END MulticastObjectServer
