/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.test.performance;

import jgroup.core.registry.DependableRegistry;
import jgroup.core.registry.RegistryFactory;

/**
 *  Client used to shutdown a server remotely.
 *
 *  @author Hein Meling
 *  @since Jgroup 2.1
 */
public class ShutdownClient
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Set of servers supported for running tests through
   *  the <code>SpeedTest</code> interface.
   */
  private static final String[] supportedServers = new String[] {
    "Jgroup/PerformanceServer",
    "ARM/ReplicatedServer",
    "Jgroup/SpeedTest"
  };


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Main
  ////////////////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] argv)
    throws Exception
  {
    DependableRegistry reg = RegistryFactory.getRegistry();
    String[] servers = reg.list();
    RemoteShutdown srv = null;
    for (int i = 0; srv == null && i < servers.length; i++) {
      for (int j = 0; srv == null && j < supportedServers.length; j++) {
        if (servers[i].equals(supportedServers[j])) {
          srv = (RemoteShutdown) reg.lookup(servers[i]);
          System.out.println("Found supported server: " + servers[i]);
        }
      }
    }
    if (srv == null) {
      System.out.println("No supported servers found");
      System.exit(0);
    }
    // Send multicast prepare shutdown to all servers
    srv.preShutdown();
    // Do shutdown on an arbitrary server
    srv.shutdown(0);
  }

} // END ShutdownClient
