/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.test.performance.upgrade;

import jgroup.core.registry.DependableRegistry;
import jgroup.core.registry.RegistryFactory;
import jgroup.test.performance.SpeedTest;

/**
 *  Test for measuring the performance of GMI invocations.
 *  Can be executed remotely through the <t>Executor</t> class,
 *  since it implements the <t>Server</t> interface.
 *
 *  @author       Marcin Solarski
 *  @since        Jgroup 2.1
 */
public class UpgradeSpeedTestClient
{


  private static void help() {
     System.out.println("UpgradeSpeedTestClient [-v][-method N][-calibrate C][-rate R][-time T][-clients][-server ServerName]");
  }

  
  public static void main(String[] argv)
    throws Exception
  {
    if( argv.length <1 ) help();
    boolean verbose = (PUtil.getStringParameter(argv, "-v", "verbose").compareTo("verbose") != 0);
    int method = PUtil.getIntParameter(argv, "-method", "1");
    int calibReqCallNo = PUtil.getIntParameter(argv, "-calibrate", "10");
    int rps = PUtil.getIntParameter(argv, "-rate", "1");
    int expTime = PUtil.getIntParameter(argv, "-time", "10");
    int client_no = PUtil.getIntParameter(argv, "-clients", "1");
    String serverName = PUtil.getStringParameter(argv, "-server", "UpgradeServer");
    if( verbose ) 
       System.out.println("Testing server " + serverName + " calibrating with " + calibReqCallNo + " calls of method " + method + " with rate " + rps + " sending for each of " + client_no + " clients for time of " + expTime +" sec.");
    ClientThreadPool client[] = new ClientThreadPool[client_no];
    
    DependableRegistry reg = RegistryFactory.getRegistry();
    SpeedTest server = (SpeedTest) reg.lookup(serverName);
    int times = expTime * rps;
    for(int i=0; i<client_no; i++) {
      client[i]= new ClientThreadPool(method, calibReqCallNo, rps, times, server);
      client[i].start();
    }
    ClientThreadPool.allStart();
  }

 

  /** True when the action requested is completed */
  private static boolean completed = false;
  private int method;
  private int rps;
  private int times;
  private int calibReqCallNo;
  private String serverName;
  
  public UpgradeSpeedTestClient(int method, int calibReqCallNo, int rps, int times, String serverName)
  {
     this.method = method;
     this.calibReqCallNo = calibReqCallNo;
     this.rps = rps;
     this.times = times;
     this.serverName = serverName;

  }


  public synchronized void start()
    throws Exception
  {
    UpgradeClientTest test = new UpgradeClientTest(serverName);
    test.calibrate(method, calibReqCallNo);
    test.generate_traffic(rps, times);
    
    completed = true;
    notify();
  }

  public synchronized void halt()
    throws Exception
  {
    while (!completed)
      try { wait(); } catch (Exception e) { }
  }

} // END UpgradeSpeedTestClient
