/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.arm;

import jgroup.core.arm.ReplicationManager;
import jgroup.core.registry.DependableRegistry;
import jgroup.core.registry.RegistryFactory;
import jgroup.relacs.config.AppConfig;
import jgroup.util.Abort;

/**
 *  Client program for accessing the Replication Manager.
 *
 *  @author Hein Meling
 *  @since Jgroup 1.2
 */
public class ManagementClient
{

  public static void main(String argv[])
    throws Exception
  {
    /*
     * Obtain a proxy for the dependable registry running in the
     * distributed system described in the config.xml file.
     */
    DependableRegistry dregistry = RegistryFactory.getRegistry();

    /*
     * Retrieve a proxy for an object group implementing the
     * ReplicationManager interface registered under the name
     * "ReplicationManager".
     */
    ReplicationManager replicaManager =
      (ReplicationManager) dregistry.lookup("Jgroup/ReplicationManager");
    System.out.println("Successful lookup: ReplicationManager");

    AppConfig app = null;
    String clazz = System.getProperty("arm.deploy.class");
    if (clazz != null && clazz.length() > 0) {
      app = AppConfig.getApplication(clazz);
    }

    try {
      if (argv[0].equals("create")) {
        System.out.println("Creating group: " + app);
        replicaManager.createGroup(app);
      } else if (argv[0].equals("remove")) {
        System.out.println("Removing group: " + app);
        replicaManager.removeGroup(app);
      }
    } catch (Exception exception) {
      throw new Abort("Failed to create server", exception);
    }
    System.exit(0);
  }

} // END ManagementClient
