/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core;

import java.lang.reflect.InvocationHandler;
import java.rmi.Remote;
import java.rmi.RemoteException;
import java.rmi.server.ExportException;

import jgroup.core.registry.DependableRegistry.RegistryEntry;


/**
 *  This interface is used to obtain the identifier of the current
 *  EGMI invocation and to get a registry entry and bootstrap handler
 *  for the dependable registry.
 *
 *  @author Alberto Montresor
 *  @author Hein Meling
 *  @since Jgroup 0.8
 */
public interface ExternalGMIService
  extends Layer
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Nested interface
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * This interface must be implemented by all EGMI services that can
   * be used by the bootstrap mechanism.
   * 
   * @author Tor Arve Stangeland
   */
  public interface BootstrapInvocationHandler
    extends InvocationHandler, Remote
  {

    /**
     * Merge this handler with the given handler.
     * 
     * @param handler
     *   <code>BootstrapInvoationHandler</code> handler to merge with
     * 
     * @throws JgroupException if merge failed for some reason
     */
    public void merge(BootstrapInvocationHandler handler)
      throws JgroupException, RemoteException;
  
    /**
     * Return the invocation handler type
     */
    public String getType()
      throws RemoteException;

  } // END of BootstrapInvocationHandler


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Interface methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Returns the invocation identifier for the current external group
   *  method invocation.
   */
  public IID getIdentifier();

  /**
   *  Returns the registry entry type required for this implementation
   *  of the external GMI service.
   */
  public RegistryEntry getRegistryEntry(String serviceName)
    throws JgroupException;

  /**
   * Returns an <code>BootstrapInvocationHandler</code> that can be bound
   * to a normal Java RMI registry instance and later merged with others.
   */
  public BootstrapInvocationHandler getBootstrapHandler()
    throws JgroupException;

  /**
   * Returns a proxy exported with the <code>BasicJeriExporter</code>.
   * 
   * @param impl the remote object to be exported
   * @return the exported proxy
   * @throws JgroupException if the object could not be exported
   */
  public Remote getProxy(Remote impl)
    throws ExportException;

} // END ExternalGMIService
