/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core;

import java.io.Externalizable;

/**
 *  Instances of classes that implement this interface uniquely identify
 *  invocations issued by a client.  Each invocation identifier is
 *  composed by a virtual machine identifier, which identifies the
 *  client, and a progressive counter used to distinguish among
 *  invocations performed by the same client.
 *
 *  @author Alberto Montresor
 *  @since Jgroup 0.9
 */
public interface IID
  extends Externalizable
{

  /**
   * Returns the <code>VMID</code> identifier of the virtual machine
   * that generated this invocation.
   */
  public VMID getVmid();


  /**
   * Returns the sequential counter identifying this particular
   * invocation.
   */
  public int getCounter();

} // END IID
