/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core;

/**
 *  In order to be notified of state updates, the server replicas
 *  must implement this interface.  Servers implementing this interface
 *  should be considered <i>semi-actively</i> replicated, were one
 *  of the servers is elected as the group leader.
 *
 *  Note that it is required that the state object returned by the
 *  <code>getState()</code> method does implement/override the
 *  <code>hashCode()</code> method, since that is used to determine
 *  if the leader state should be sent to the followers.
 *
 *  @author Hein Meling
 *  @since 3.0
 */
public interface StateListener
{

  /**
   *  Method <code>getState</code> is invoked by the group leader,
   *  and should return its current state.
   *
   *  @return 
   *    The state object
   */
  public Object getState();

  /**
   *  Method <code>putState</code> is invoked on followers to inform
   *  them about the new state of the group leader.
   *
   *  @param state
   *    The state object
   */
  public void putState(Object state);

} // END StateListener
