/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core.multicast;

import java.io.InputStream;

import jgroup.core.MemberId;

/**
 *  This interface enables members to receive message delivery
 *  notifications.  Members implementing this interface must be able to
 *  react in a suitable way to the delivery of messages composed either
 *  by single objects or an input stream.
 *
 *  @author Alberto Montresor
 *  @author Hein Meling
 *  @since Jgroup 0.7
 */
public interface MulticastListener
{

  /**
   *  Returns a string naming the protocol implemented by this multicast
   *  listener.
   */
  public String getProtocolName();


  /**
   * Upcall that is invoked by Jgroup to deliver a message <code>msg</code>,
   * corresponding to an input stream from which the message may be read.
   *
   * @param msg   the input stream from which the message can be read.
   * @param sender  the sender of the multicast message
   * @param seqNo  the sequence number of this multicast message 
   * @return an object that will be delivered to the invoker through the
   * <tt>AckListener</tt> object specified when multicasting the message.
   */
  public Object deliverStream(InputStream msg, MemberId sender, int seqNo);


  /**
   * Upcall that is invoked by Jgroup to deliver a message <code>msg</code>,
   * corresponding to a single serialized object.
   *
   * @param msg    the object that was multicasted.
   * @param sender  the sender of the multicast message
   * @param seqNo  the sequence number of this multicast message 
   * @return an object that will be delivered to the invoker through the
   * <tt>AckListener</tt> object specified when multicasting the message.
   */
  public Object deliverObject(Object msg, MemberId sender, int seqNo);

} // END MulticastListener
