/*
 * Copyright (c) 1998-2005 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */
package jgroup.core.registry;

import java.rmi.AccessException;
import java.rmi.NotBoundException;
import java.rmi.Remote;
import java.rmi.RemoteException;

import jgroup.core.ExternalGMIListener;

/**
 * Interface used by clients to lookup proxy in 
 * registry.
 * 
 * @author Rohnny Moland
 */
public interface LookupRegistry
  extends ExternalGMIListener
{
  /**
   * Returns a proxy for the remote object group associated with the specified name in the
   * registry. When LeaseLayer is used, it checks to see if any servers have expired
   * leasetimes.
   *
   * @param name      the name associated with the remote object group
   * @return          a proxy for the remote object group
   *
   * @exception RemoteException If remote operation failed.
   * @exception NotBoundException if there is no object group with this name in the
   *              registry.
   * @exception AccessException If this operation is not permitted.
   */
  public Remote lookup(String name)
    throws RemoteException, NotBoundException, AccessException;
  
  /**
   * Returns an array containing the remote object group names registered in the
   * registry. When LeaseLayer is used, it checks to see if any servers have expired
   * leasetimes.
   *
   * @exception RemoteException If remote operation failed.
   * @exception AccessException If this operation is not permitted.
   */
  public String[] list()
    throws RemoteException, AccessException;

} // END LookupRegistry

