/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.daemon;

import java.rmi.Remote;
import java.rmi.RemoteException;

import jgroup.core.EndPoint;
import jgroup.core.MemberId;
import jgroup.relacs.events.Event;


/**
 *  The <code>DaemonService</code> interface describes the methods
 *  accessible remotely (same host, but distinct JVMs) from the daemon.
 *
 *  @author Hein Meling
 *  @since Jgroup 1.2
 */
public interface DaemonService
  extends Remote
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Service name used to register each daemon in its bootstrap
   *  registry.
   */
  public static final String DAEMON_NAME = "Daemon";

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Returns a new member id for a new member.  The new member id is
   *  obtained by concatenating the endpoint of this daemon, the
   *  incarnation number used to distinguish different incarnation of
   *  the same endpoint, and a sequence number used to distinguish
   *  different members.
   */
  public MemberId getMemberId(EndPoint endpoint)
    throws RemoteException;


  /**
   *  Returns the number of members associated with this Jgroup daemon.
   */
  public int members()
    throws RemoteException;


  /**
   *  Adds an event generated by a member to the local queue of events.
   */
  public void addEvent(Event event)
    throws RemoteException;
  

} // END DaemonService
