/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.gm;

import jgroup.relacs.events.Event;

/**
 *  The <code>DispatcherListener</code> interface must be implemented by
 *  layers that wish to receive event messages originated from the
 *  daemon.
 *
 *  @author Hein Meling
 *  @since Jgroup 1.2
 */
public interface DispatcherListener
{

  /**
   *  Returns the set of event types supported by this listener.  Legal
   *  event types are given in the <code>EventTags</code> interface.
   */
  public int[] eventTypes();

  /**
   *  This method is invoked by a dispatcher to notify a listener
   *  about an event. 
   *
   *  @param event
   *    The <code>Event</code> object to be processed.
   */
  public void notifyEvent(Event event);

} // END DispatcherListener
