/*
 * Copyright (c) 1998-2003 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */
package jgroup.relacs.gmi;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Proxy;
import java.rmi.Remote;
import java.rmi.RemoteException;
import java.util.Iterator;

import jgroup.core.MemberId;
import jgroup.core.registry.DependableRegistry.RegistryEntry;
import net.jini.export.Exporter;
import net.jini.jeri.BasicILFactory;
import net.jini.jeri.BasicJeriExporter;
import net.jini.jeri.ObjectEndpoint;
import net.jini.jeri.InvocationLayerFactory.Instances;
import net.jini.jeri.tcp.TcpServerEndpoint;

/**
 * The registry entry type required to use the BasicJeriExport
 * in binding with the dependable registry.
 *
 * @author Hein Meling
 */
public class BasicJeriRegistryEntry
  implements RegistryEntry
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  private static final long serialVersionUID = 4490998440934560367L;

  public final static String TYPE = "BasicJeri";


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Endpoint */
  private MemberId me;

  /** Service name */
  private String service;

  /** The invocation layer factory */
  private BasicILFactory ilfactory;


  private ObjectEndpoint oe;


  private Remote impl;


  private TcpServerEndpoint se;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Create empty entry, for externalization */
  public BasicJeriRegistryEntry() {}

  
  /**
   * Create a new <code>BasicJeriRegistryEntry</code>.
   */
  BasicJeriRegistryEntry(Remote impl, ObjectEndpoint oe)
  {
    this.se = TcpServerEndpoint.getInstance(0);
    this.ilfactory = new BasicILFactory();
    Exporter exporter = new BasicJeriExporter(se, ilfactory);
    this.impl = impl;
    this.oe = oe;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from DependableRegistry.RegistryEntry
  ////////////////////////////////////////////////////////////////////////////////////////////

  /* (non-Javadoc)
   * @see jgroup.core.registry.DependableRegistry.RegistryEntry#getType()
   */
  public String getType()
  {
    return TYPE;
  }


  /* (non-Javadoc)
   * @see jgroup.core.registry.DependableRegistry.RegistryEntry#createInvocationHandler(java.lang.String, java.util.Iterator)
   */
  public InvocationHandler createInvocationHandler(String serviceName, Iterator entries)
    throws RemoteException
  {
    Instances inst = ilfactory.createInstances(impl, oe, se);
    return Proxy.getInvocationHandler(inst.getProxy());
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Externalizable inherited through DependableRegistry.RegistryEntry
  ////////////////////////////////////////////////////////////////////////////////////////////

  /* (non-javadoc)
   * @see java.io.Externalizable#readExternal(ObjectInput)
   */
  public void readExternal(ObjectInput in)
    throws IOException, ClassNotFoundException
  {
    service = (String) in.readObject();
    me = (MemberId) in.readObject();
  }

  /* (non-javadoc)
   * @see java.io.Externalizable#writeExternal(ObjectOutput)
   */
  public void writeExternal(ObjectOutput out)
    throws IOException
  {
    out.writeObject(service);
    out.writeObject(me);
  }

} // END JeriRegistryEntry
