/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.types;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

/**
 *  The <code>Flag</code> class wraps a value of the relacs daemon type 
 *  "flag" in an object. A flag is a boolean type that can assume the
 *  values {0, 1}. 
 *
 *  @author Alberto Montresor
 *  @author Hein Meling
 *  @since  Jgroup 1.2
 */
public final class Flag
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Size of this object in bytes */
  public static final int SIZE = 1;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /** Wrapped value */
  private int value;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Creates a <CODE>Flag</CODE> object containing the specified
   *  value.
   */
  public Flag(int value)
  {
    this.value = value;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Accessor method
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Returned the wrapped value.
   */
  public int getValue()
  {
    return value;
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Marshaling / unmarshaling methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Marshals the specified flag to an outgoing message.
   */
  public static void marshal(ObjectOutput msg, boolean value)
    throws IOException
  {
    msg.writeBoolean(value);
  }
  
  /**
   *  Unmarshals a flag from an incoming message.
   */
  public static boolean unmarshal(ObjectInput msg)
    throws IOException
  {
    return msg.readBoolean();
  }

  /**
   *  Unmarshals a flag from a byte.
   */
  public static boolean unmarshal(byte value)
  {
    return (value == 1 ? true : false);
  }

} // END Flag
