/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.types;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

/**
 *  The <code>MessageLen</code> class wraps a value of the relacs daemon type 
 *  "message length" in an object. A message lenght describes the length of
 *  the payload field of a multicast message. An object of type 
 *  <code>MessageLen</code> contains a single field whose type is int. 
 *
 *  @author Alberto Montresor
 *  @since  Jgroup 1.2
 */

public final class MessageLen
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Size of this object in bytes */
  public static final int SIZE = 4;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /** Wrapped value */
  private int value;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Creates a <CODE>MessageLen</CODE> object containing the specified
   *  value.
   */
  public MessageLen(int value)
  {
    this.value = value;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Accessor method
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Returned the wrapped value.
   */
  public int getValue()
  {
    return value;
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Marshaling / unmarshaling methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Marshals the specified message id to an outgoing message.
   */
  public static void marshal(ObjectOutput msg, int value)
    throws IOException
  {
    msg.writeInt(value);
  }
  
  /**
   *  Unmarshals a message id from an incoming message.
   */
  public static int unmarshal(ObjectInput msg)
    throws IOException
  {
    return msg.readInt();
  }

} // END MessageLen
