/*
 * Copyright (c) 1998-2006 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.util.log;

/**
 * ExperimentEvent 
 *
 * @author Hein Meling <hein.meling@uis.no>
 */
public class ExperimentEvent
  extends Event
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  private static final long serialVersionUID = -4491709600445800676L;

  /**
   * Supported experiment event types.
   */
  public enum Type implements EventType { Begin, End }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * The round number for this experiment event
   */
  private int round;

  /**
   * The rerun number for this experiment event
   */
  private int rerun;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  public ExperimentEvent(EventType type, int round, int rerun)
  {
    super(type, "Round: " + round + ((rerun == -1) ? "" : ", rerun=" + rerun));
    this.round = round;
    this.rerun = rerun;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Access Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * @return Returns the round of this experiment event.
   */
  public int getRound()
  {
    return round;
  }

  /**
   * @return Returns the rerun number for this experiment event
   */
  public int getRerun()
  {
    return rerun;
  }

  /**
   * @return Returns true if the event type is <code>End</code>; otherwise false.
   * 
   * @see jgroup.util.log.Event#isLastEvent()
   */
  @Override
  public boolean isLastEvent()
  {
    return type == Type.End;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Object
  ////////////////////////////////////////////////////////////////////////////////////////////

  public String toString()
  {
    return commonToString(true).toString();
  }

} // END ExperimentEvent
